@@ -1,6 +1,6 @@
 per.variance<- function(object){  
   per <- NULL  
-  if((prod(object$keepY==rep(dim(object$Y),object$ncomp))==1)|is.null(object$keepY)) {
+  if((prod(object$keepY==rep(dim(object$Y)[2],object$ncomp))==1)|is.null(object$keepY)) {
   for (h in 1:object$ncomp)  {
     per <- c(per,mean(apply(matrix(object$variates$X[,h],ncol=1)%*%matrix(t(object$mat.d)[h,],nrow=1),MARGIN=2,FUN=var)/apply(object$Y,MARGIN=2,FUN=var)))
   }
